==> ejc-ecard-impl-3.0.0-20230703.085343-31-sources.jar: com/ejianc/business/bi/controller/IndustrialDistributionController.java <==
package com.ejianc.business.bi.controller;

import java.io.Serializable;

import com.ejianc.business.bi.vo.BIDataIndustrialDistributionVO;
import com.ejianc.business.bi.vo.BIIndustrialDistributionVO;
import com.ejianc.business.bi.vo.BILinksIndustrialDistributionVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.bi.bean.IndustrialDistributionEntity;
import com.ejianc.business.bi.service.IIndustrialDistributionService;
import com.ejianc.business.bi.vo.IndustrialDistributionVO;

/**
 * BI集团产业分布
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("industrialDistribution")
public class IndustrialDistributionController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IIndustrialDistributionService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IndustrialDistributionVO> saveOrUpdate(@RequestBody IndustrialDistributionVO saveOrUpdateVO) {
    	IndustrialDistributionEntity entity = BeanMapper.map(saveOrUpdateVO, IndustrialDistributionEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                //entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	IndustrialDistributionVO vo = BeanMapper.map(entity, IndustrialDistributionVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IndustrialDistributionVO> queryDetail(Long id) {
    	IndustrialDistributionEntity entity = service.selectById(id);
    	IndustrialDistributionVO vo = BeanMapper.map(entity, IndustrialDistributionVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<IndustrialDistributionVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (IndustrialDistributionVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(IndustrialDistributionVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<IndustrialDistributionVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        IPage<IndustrialDistributionEntity> page = service.queryPage(param,false);
        IPage<IndustrialDistributionVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), IndustrialDistributionVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<IndustrialDistributionEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("IndustrialDistribution-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refIndustrialDistributionData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<IndustrialDistributionVO>> refIndustrialDistributionData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<IndustrialDistributionEntity> page = service.queryPage(param,false);
        IPage<IndustrialDistributionVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), IndustrialDistributionVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }


    /**
     * @Description queryBIDetail 查询详情
     * @param
     */
    @RequestMapping(value = "/queryBIDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<BIIndustrialDistributionVO> queryBIDetail(@RequestParam(value = "orgId", required = true) Long orgId,
                                                                    @RequestParam(value = "dateIn", required = true) Integer dateIn) {
        QueryParam param = new QueryParam();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("dr", new Parameter(QueryParam.EQ, 0));
        List<IndustrialDistributionEntity> industrialDistributionEntities = service.queryList(param);

        ArrayList<BIDataIndustrialDistributionVO> biDataVOS = new ArrayList<>();
        ArrayList<BILinksIndustrialDistributionVO> biLinksVOS = new ArrayList<>();

        for (int i = 0; i < industrialDistributionEntities.size(); i++) {
            BIDataIndustrialDistributionVO biDataVO = new BIDataIndustrialDistributionVO();
            BILinksIndustrialDistributionVO biLinksVO = new BILinksIndustrialDistributionVO();

            biDataVO.setName(industrialDistributionEntities.get(i).getName());
            biDataVO.setDes(industrialDistributionEntities.get(i).getName()+"des");
            biDataVO.setSymbolSize(industrialDistributionEntities.get(i).getCount());
            biDataVO.setId(industrialDistributionEntities.get(i).getId());

            //是施工项目部的标记为2
            if (industrialDistributionEntities.get(i).getParentId()!= null && industrialDistributionEntities.get(i).getParentId().equals(726351188055871553L)){
                biDataVO.setCategory(1);
            }else {
                biDataVO.setCategory(0);
            }

            //上级板块不为空，有链接
            if (industrialDistributionEntities.get(i).getParentId() != null){
                biLinksVO.setSource(industrialDistributionEntities.get(i).getParentName());
                biLinksVO.setTarget(industrialDistributionEntities.get(i).getName());
                biLinksVO.setName("link"+i);
                biLinksVO.setDes("link"+i+"des");
                biLinksVOS.add(biLinksVO);
            }

            biDataVOS.add(biDataVO);
        }


        BIIndustrialDistributionVO biIndustrialDistributionVO = new BIIndustrialDistributionVO();
        biIndustrialDistributionVO.setBiDataVOS(biDataVOS);
        biIndustrialDistributionVO.setBiLinksVOS(biLinksVOS);

        return CommonResponse.success("查询详情数据成功！",biIndustrialDistributionVO);
    }
}

==> ejc-ecard-impl-3.0.0-20231019.024052-46-sources.jar: com/ejianc/business/bi/controller/IndustrialDistributionController.java <==
package com.ejianc.business.bi.controller;

import java.io.Serializable;

import com.ejianc.business.bi.bean.IndustrialDistributionDetailEntity;
import com.ejianc.business.bi.service.IIndustrialDistributionDetailService;
import com.ejianc.business.bi.vo.*;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.bi.bean.IndustrialDistributionEntity;
import com.ejianc.business.bi.service.IIndustrialDistributionService;

/**
 * BI集团产业分布
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("industrialDistribution")
public class IndustrialDistributionController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IIndustrialDistributionService service;

    @Autowired
    private IIndustrialDistributionDetailService detailService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IndustrialDistributionVO> saveOrUpdate(@RequestBody IndustrialDistributionVO saveOrUpdateVO) {
    	IndustrialDistributionEntity entity = BeanMapper.map(saveOrUpdateVO, IndustrialDistributionEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                //entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	IndustrialDistributionVO vo = BeanMapper.map(entity, IndustrialDistributionVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IndustrialDistributionVO> queryDetail(Long id) {
    	IndustrialDistributionEntity entity = service.selectById(id);
    	IndustrialDistributionVO vo = BeanMapper.map(entity, IndustrialDistributionVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<IndustrialDistributionVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (IndustrialDistributionVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(IndustrialDistributionVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<IndustrialDistributionVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        IPage<IndustrialDistributionEntity> page = service.queryPage(param,false);
        IPage<IndustrialDistributionVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), IndustrialDistributionVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<IndustrialDistributionEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("IndustrialDistribution-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refIndustrialDistributionData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<IndustrialDistributionVO>> refIndustrialDistributionData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<IndustrialDistributionEntity> page = service.queryPage(param,false);
        IPage<IndustrialDistributionVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), IndustrialDistributionVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }


    /**
     * @Description queryBIDetail 查询详情
     * @param
     */
    @RequestMapping(value = "/queryBIDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<BIIndustrialDistributionVO> queryBIDetail(@RequestParam(value = "orgId", required = true) Long orgId,
                                                                    @RequestParam(value = "dateIn", required = true) Integer dateIn) {
        QueryParam param = new QueryParam();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("dr", new Parameter(QueryParam.EQ, 0));
        List<IndustrialDistributionEntity> industrialDistributionEntities = service.queryList(param);

        List<IndustrialDistributionDetailEntity> industrialDistributionDetailEntities = detailService.queryList(param);

        ArrayList<BIDataIndustrialDistributionVO> biDataVOS = new ArrayList<>();
        ArrayList<BILinksIndustrialDistributionVO> biLinksVOS = new ArrayList<>();

        for (int i = 0; i < industrialDistributionEntities.size(); i++) {
            BIDataIndustrialDistributionVO biDataVO = new BIDataIndustrialDistributionVO();
            BILinksIndustrialDistributionVO biLinksVO = new BILinksIndustrialDistributionVO();

            biDataVO.setName(industrialDistributionEntities.get(i).getName());
            biDataVO.setDes(industrialDistributionEntities.get(i).getName()+"des");
            biDataVO.setSymbolSize(industrialDistributionEntities.get(i).getCount());
            biDataVO.setId(industrialDistributionEntities.get(i).getId());

            ArrayList<BIDataIndustrialDistributionDetailVO> biDataIndustrialDistributionDetailVOS = new ArrayList<>();
            for (IndustrialDistributionDetailEntity industrialDistributionDetailEntity : industrialDistributionDetailEntities) {
                if (industrialDistributionDetailEntity.getZhuId().equals(industrialDistributionEntities.get(i).getId())){
                    BIDataIndustrialDistributionDetailVO biDataIndustrialDistributionDetailVO = new BIDataIndustrialDistributionDetailVO();
                    biDataIndustrialDistributionDetailVO.setUnitName(industrialDistributionDetailEntity.getDeptName());
                    biDataIndustrialDistributionDetailVO.setUrl(industrialDistributionDetailEntity.getAddress());
                    biDataIndustrialDistributionDetailVOS.add(biDataIndustrialDistributionDetailVO);
                }
            }
            biDataVO.setUnitList(biDataIndustrialDistributionDetailVOS);

            //是施工项目部的标记为2
            if (industrialDistributionEntities.get(i).getParentId()!= null && industrialDistributionEntities.get(i).getParentId().equals(726351188055871553L)){
                biDataVO.setCategory(1);
            }else {
                biDataVO.setCategory(0);
            }

            //上级板块不为空，有链接
            if (industrialDistributionEntities.get(i).getParentId() != null){
                biLinksVO.setSource(industrialDistributionEntities.get(i).getParentName());
                biLinksVO.setTarget(industrialDistributionEntities.get(i).getName());
                biLinksVO.setName("link"+i);
                biLinksVO.setDes("link"+i+"des");
                biLinksVOS.add(biLinksVO);
            }

            biDataVOS.add(biDataVO);
        }


        BIIndustrialDistributionVO biIndustrialDistributionVO = new BIIndustrialDistributionVO();
        biIndustrialDistributionVO.setBiDataVOS(biDataVOS);
        biIndustrialDistributionVO.setBiLinksVOS(biLinksVOS);

        return CommonResponse.success("查询详情数据成功！",biIndustrialDistributionVO);
    }
}
